@@ -21,4 +21,4 @@ class ERP(XMLScalar):
     _TYPE = 'sdf'
 
     def __init__(self, default=0.2):
-        XMLScalar.__init__(self, default, min_value=0)
+        super(ERP, self).__init__(default, min_value=0)
