@@ -20,4 +20,4 @@ class MaxDist(XMLScalar):
     _TYPE = 'sdf'
 
     def __init__(self, default=0):
-        XMLScalar.__init__(self, default)
+        super(MaxDist, self).__init__(default)
