@@ -28,7 +28,7 @@ class Scan(XMLBase):
     )
 
     def __init__(self):
-        XMLBase.__init__(self)
+        super(Scan, self).__init__()
         self.reset()
 
     @property
